==> qt4-x11_4.4.0.orig.tar.gz: qt-x11-opensource-src-4.4.0/translations/qvfb_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh">
<defaultcodec></defaultcodec>
<context>
    <name>AnimationSaveWidget</name>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="1027"/>
        <source>Record</source>
        <translation>录像</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="825"/>
        <source>Reset</source>
        <translation>重置</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="827"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="845"/>
        <source>Save in MPEG format (requires netpbm package installed)</source>
        <translation>以 MPEG 格式保存 (需要安装 netpbm 包)</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="1059"/>
        <source>Click record to begin recording.</source>
        <translation>点击录像开始录像。</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="1091"/>
        <source>Finished saving.</source>
        <translation>完成保存。</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="1028"/>
        <source>Paused. Click record to resume, or save if done.</source>
        <translation>暂停。点击录像继续，或者如果已经完成录制，点击保存。</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="1034"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="1035"/>
        <source>Recording...</source>
        <translation>录像中...</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="1075"/>
        <source>Saving... </source>
        <translation>保存中... </translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="1083"/>
        <source>Save animation...</source>
        <translation>保存动画...</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="1085"/>
        <source>Save canceled.</source>
        <translation>保存已被取消。</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="1094"/>
        <source>Save failed!</source>
        <translation>保存失败！</translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="25"/>
        <source>Configure</source>
        <translation>配置</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="72"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="93"/>
        <source>176x220 &quot;SmartPhone&quot;</source>
        <translation>176x220 &quot;SmartPhone&quot;</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="100"/>
        <source>240x320 &quot;PDA&quot;</source>
        <translation>240x320 &quot;PDA&quot;</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="107"/>
        <source>320x240 &quot;TV&quot; / &quot;QVGA&quot;</source>
        <translation>320x240 &quot;TV&quot; / &quot;QVGA&quot;</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="114"/>
        <source>640x480 &quot;VGA&quot;</source>
        <translation>640x480 &quot;VGA&quot;</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="121"/>
        <source>800x600</source>
        <translation>800x600</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="128"/>
        <source>1024x768</source>
        <translation>1024x768</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="158"/>
        <source>Custom</source>
        <translation>自定义</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="202"/>
        <source>Depth</source>
        <translation>色深</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="223"/>
        <source>1 bit monochrome</source>
        <translation>1位黑白色</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="230"/>
        <source>4 bit grayscale</source>
        <translation>4位灰度色</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="237"/>
        <source>8 bit</source>
        <translation>8位</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="244"/>
        <source>12 (16) bit</source>
        <translation>12(16)位</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="258"/>
        <source>16 bit</source>
        <translation>16位</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="265"/>
        <source>18 bit</source>
        <translation>18位</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="272"/>
        <source>24 bit</source>
        <translation>24位</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="279"/>
        <source>32 bit</source>
        <translation>32位</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="315"/>
        <source>Skin</source>
        <translation>皮肤</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="329"/>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="339"/>
        <source>Emulate touch screen (no mouse move)</source>
        <translation>模拟触摸屏(没有鼠标移动)</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="346"/>
        <source>Emulate LCD screen (Only with fixed zoom of 3.0 times magnification)</source>
        <translation>模拟 LCD 屏幕(只固定放大3倍)</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="372"/>
        <source>&lt;p&gt;Note that any applications using the virtual framebuffer will be terminated if you change the Size or Depth &lt;i&gt;above&lt;/i&gt;. You may freely modify the Gamma &lt;i&gt;below&lt;/i&gt;.</source>
        <translation>&lt;p&gt;请注意如果你改变&lt;i&gt;上面的&lt;/i&gt;大小或者色深，任何使用虚拟帧缓冲的应用程序都将会受到影响。你可以自由地修改&lt;i&gt;下面的&lt;/i&gt; Gamma。</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="382"/>
        <source>Gamma</source>
        <translation>Gamma</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="406"/>
        <source>Blue</source>
        <translation>蓝色</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="1901"/>
        <source>1.0</source>
        <translation>1.0</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="902"/>
        <source>Green</source>
        <translation>绿色</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="1398"/>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="1894"/>
        <source>Red</source>
        <translation>红色</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="2390"/>
        <source>Set all to 1.0</source>
        <translation>设定所有值为1.0</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="2433"/>
        <source>&amp;OK</source>
        <translation>确认(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="2446"/>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="251"/>
        <source>15 bit</source>
        <translation>15位</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/config.ui" line="286"/>
        <source>32 bit ARGB</source>
        <translation>32位 ARGB</translation>
    </message>
</context>
<context>
    <name>QVFb</name>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="607"/>
        <source>Browse...</source>
        <translation>浏览...</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="733"/>
        <source>Load Custom Skin...</source>
        <translation>载入自定义皮肤...</translation>
    </message>
    <message>
        <location filename="../../depot/qt/4.4/tools/qvfb/qvfb.cpp" line="734"/>
        <source>All QVFB Skins (*.skin)</source>
        <translation>所有 QVFB 皮肤 (*.skin)</translation>
    </message>
</context>
</TS>

==> qt4-x11_4.4.3.orig.tar.gz: qt-x11-opensource-src-4.4.3/translations/qvfb_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh">
<context>
    <name>AnimationSaveWidget</name>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1028"/>
        <source>Record</source>
        <translation>录像</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="826"/>
        <source>Reset</source>
        <translation>重置</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="828"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="846"/>
        <source>Save in MPEG format (requires netpbm package installed)</source>
        <translation>以 MPEG 格式保存 (需要安装 netpbm 包)</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1060"/>
        <source>Click record to begin recording.</source>
        <translation>点击录像开始录像。</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1092"/>
        <source>Finished saving.</source>
        <translation>完成保存。</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1029"/>
        <source>Paused. Click record to resume, or save if done.</source>
        <translation>暂停。点击录像继续，或者如果已经完成录制，点击保存。</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1035"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1036"/>
        <source>Recording...</source>
        <translation>录像中...</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1076"/>
        <source>Saving... </source>
        <translation>保存中... </translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1084"/>
        <source>Save animation...</source>
        <translation>保存动画...</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1086"/>
        <source>Save canceled.</source>
        <translation>保存已被取消。</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1095"/>
        <source>Save failed!</source>
        <translation>保存失败！</translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <location filename="../tools/qvfb/config.ui" line="25"/>
        <source>Configure</source>
        <translation>配置</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="72"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="93"/>
        <source>176x220 &quot;SmartPhone&quot;</source>
        <translation>176x220 &quot;SmartPhone&quot;</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="100"/>
        <source>240x320 &quot;PDA&quot;</source>
        <translation>240x320 &quot;PDA&quot;</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="107"/>
        <source>320x240 &quot;TV&quot; / &quot;QVGA&quot;</source>
        <translation>320x240 &quot;TV&quot; / &quot;QVGA&quot;</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="114"/>
        <source>640x480 &quot;VGA&quot;</source>
        <translation>640x480 &quot;VGA&quot;</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="121"/>
        <source>800x600</source>
        <translation>800x600</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="128"/>
        <source>1024x768</source>
        <translation>1024x768</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="158"/>
        <source>Custom</source>
        <translation>自定义</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="202"/>
        <source>Depth</source>
        <translation>色深</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="223"/>
        <source>1 bit monochrome</source>
        <translation>1位黑白色</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="230"/>
        <source>4 bit grayscale</source>
        <translation>4位灰度色</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="237"/>
        <source>8 bit</source>
        <translation>8位</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="244"/>
        <source>12 (16) bit</source>
        <translation>12(16)位</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="258"/>
        <source>16 bit</source>
        <translation>16位</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="265"/>
        <source>18 bit</source>
        <translation>18位</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="272"/>
        <source>24 bit</source>
        <translation>24位</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="279"/>
        <source>32 bit</source>
        <translation>32位</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="315"/>
        <source>Skin</source>
        <translation>皮肤</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="329"/>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="339"/>
        <source>Emulate touch screen (no mouse move)</source>
        <translation>模拟触摸屏(没有鼠标移动)</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="346"/>
        <source>Emulate LCD screen (Only with fixed zoom of 3.0 times magnification)</source>
        <translation>模拟 LCD 屏幕(只固定放大3倍)</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="372"/>
        <source>&lt;p&gt;Note that any applications using the virtual framebuffer will be terminated if you change the Size or Depth &lt;i&gt;above&lt;/i&gt;. You may freely modify the Gamma &lt;i&gt;below&lt;/i&gt;.</source>
        <translation>&lt;p&gt;请注意如果你改变&lt;i&gt;上面的&lt;/i&gt;大小或者色深，任何使用虚拟帧缓冲的应用程序都将会受到影响。你可以自由地修改&lt;i&gt;下面的&lt;/i&gt; Gamma。</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="382"/>
        <source>Gamma</source>
        <translation>Gamma</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="406"/>
        <source>Blue</source>
        <translation>蓝色</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="1901"/>
        <source>1.0</source>
        <translation>1.0</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="902"/>
        <source>Green</source>
        <translation>绿色</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="1398"/>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="1894"/>
        <source>Red</source>
        <translation>红色</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="2390"/>
        <source>Set all to 1.0</source>
        <translation>设定所有值为1.0</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="2433"/>
        <source>&amp;OK</source>
        <translation>确认(&amp;O)</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="2446"/>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="251"/>
        <source>15 bit</source>
        <translation>15位</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="286"/>
        <source>32 bit ARGB</source>
        <translation>32位 ARGB</translation>
    </message>
</context>
<context>
    <name>QVFb</name>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="608"/>
        <source>Browse...</source>
        <translation>浏览...</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="734"/>
        <source>Load Custom Skin...</source>
        <translation>载入自定义皮肤...</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="735"/>
        <source>All QVFB Skins (*.skin)</source>
        <translation>所有 QVFB 皮肤 (*.skin)</translation>
    </message>
</context>
</TS>
